Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterTapServiceServer(s grpc.ServiceRegistrar, srv TapServiceServer)
- type ExplainRequest
- func (*ExplainRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ExplainRequest) GetAnalyze() bool
- func (x *ExplainRequest) GetArgs() []string
- func (x *ExplainRequest) GetQuery() string
- func (*ExplainRequest) ProtoMessage()
- func (x *ExplainRequest) ProtoReflect() protoreflect.Message
- func (x *ExplainRequest) Reset()
- func (x *ExplainRequest) String() string
- type ExplainResponse
- type QueryEvent
- func (*QueryEvent) Descriptor() ([]byte, []int)deprecated
- func (x *QueryEvent) GetArgs() []string
- func (x *QueryEvent) GetDuration() *durationpb.Duration
- func (x *QueryEvent) GetError() string
- func (x *QueryEvent) GetId() string
- func (x *QueryEvent) GetNPlus_1() bool
- func (x *QueryEvent) GetNormalizedQuery() string
- func (x *QueryEvent) GetOp() int32
- func (x *QueryEvent) GetQuery() string
- func (x *QueryEvent) GetRowsAffected() int64
- func (x *QueryEvent) GetSlowQuery() bool
- func (x *QueryEvent) GetStartTime() *timestamppb.Timestamp
- func (x *QueryEvent) GetTxId() string
- func (*QueryEvent) ProtoMessage()
- func (x *QueryEvent) ProtoReflect() protoreflect.Message
- func (x *QueryEvent) Reset()
- func (x *QueryEvent) String() string
- type TapServiceClient
- type TapServiceServer
- type TapService_WatchClient
- type TapService_WatchServer
- type UnimplementedTapServiceServer
- type UnsafeTapServiceServer
- type WatchRequest
- type WatchResponse
Constants ¶
const ( TapService_Watch_FullMethodName = "/tap.v1.TapService/Watch" TapService_Explain_FullMethodName = "/tap.v1.TapService/Explain" )
Variables ¶
var File_tap_v1_tap_proto protoreflect.FileDescriptor
var TapService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "tap.v1.TapService", HandlerType: (*TapServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Explain", Handler: _TapService_Explain_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Watch", Handler: _TapService_Watch_Handler, ServerStreams: true, }, }, Metadata: "tap/v1/tap.proto", }
TapService_ServiceDesc is the grpc.ServiceDesc for TapService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterTapServiceServer ¶
func RegisterTapServiceServer(s grpc.ServiceRegistrar, srv TapServiceServer)
Types ¶
type ExplainRequest ¶
type ExplainRequest struct {
Query string `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
Args []string `protobuf:"bytes,2,rep,name=args,proto3" json:"args,omitempty"`
Analyze bool `protobuf:"varint,3,opt,name=analyze,proto3" json:"analyze,omitempty"`
// contains filtered or unexported fields
}
func (*ExplainRequest) Descriptor
deprecated
func (*ExplainRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExplainRequest.ProtoReflect.Descriptor instead.
func (*ExplainRequest) GetAnalyze ¶
func (x *ExplainRequest) GetAnalyze() bool
func (*ExplainRequest) GetArgs ¶
func (x *ExplainRequest) GetArgs() []string
func (*ExplainRequest) GetQuery ¶
func (x *ExplainRequest) GetQuery() string
func (*ExplainRequest) ProtoMessage ¶
func (*ExplainRequest) ProtoMessage()
func (*ExplainRequest) ProtoReflect ¶
func (x *ExplainRequest) ProtoReflect() protoreflect.Message
func (*ExplainRequest) Reset ¶
func (x *ExplainRequest) Reset()
func (*ExplainRequest) String ¶
func (x *ExplainRequest) String() string
type ExplainResponse ¶
type ExplainResponse struct {
Plan string `protobuf:"bytes,1,opt,name=plan,proto3" json:"plan,omitempty"`
// contains filtered or unexported fields
}
func (*ExplainResponse) Descriptor
deprecated
func (*ExplainResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExplainResponse.ProtoReflect.Descriptor instead.
func (*ExplainResponse) GetPlan ¶
func (x *ExplainResponse) GetPlan() string
func (*ExplainResponse) ProtoMessage ¶
func (*ExplainResponse) ProtoMessage()
func (*ExplainResponse) ProtoReflect ¶
func (x *ExplainResponse) ProtoReflect() protoreflect.Message
func (*ExplainResponse) Reset ¶
func (x *ExplainResponse) Reset()
func (*ExplainResponse) String ¶
func (x *ExplainResponse) String() string
type QueryEvent ¶
type QueryEvent struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Op int32 `protobuf:"varint,2,opt,name=op,proto3" json:"op,omitempty"`
Query string `protobuf:"bytes,3,opt,name=query,proto3" json:"query,omitempty"`
Args []string `protobuf:"bytes,4,rep,name=args,proto3" json:"args,omitempty"`
StartTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
Duration *durationpb.Duration `protobuf:"bytes,6,opt,name=duration,proto3" json:"duration,omitempty"`
RowsAffected int64 `protobuf:"varint,7,opt,name=rows_affected,json=rowsAffected,proto3" json:"rows_affected,omitempty"`
Error string `protobuf:"bytes,8,opt,name=error,proto3" json:"error,omitempty"`
TxId string `protobuf:"bytes,9,opt,name=tx_id,json=txId,proto3" json:"tx_id,omitempty"`
NPlus_1 bool `protobuf:"varint,10,opt,name=n_plus_1,json=nPlus1,proto3" json:"n_plus_1,omitempty"`
NormalizedQuery string `protobuf:"bytes,11,opt,name=normalized_query,json=normalizedQuery,proto3" json:"normalized_query,omitempty"`
SlowQuery bool `protobuf:"varint,12,opt,name=slow_query,json=slowQuery,proto3" json:"slow_query,omitempty"`
// contains filtered or unexported fields
}
func (*QueryEvent) Descriptor
deprecated
func (*QueryEvent) Descriptor() ([]byte, []int)
Deprecated: Use QueryEvent.ProtoReflect.Descriptor instead.
func (*QueryEvent) GetArgs ¶
func (x *QueryEvent) GetArgs() []string
func (*QueryEvent) GetDuration ¶
func (x *QueryEvent) GetDuration() *durationpb.Duration
func (*QueryEvent) GetError ¶
func (x *QueryEvent) GetError() string
func (*QueryEvent) GetId ¶
func (x *QueryEvent) GetId() string
func (*QueryEvent) GetNPlus_1 ¶ added in v0.2.1
func (x *QueryEvent) GetNPlus_1() bool
func (*QueryEvent) GetNormalizedQuery ¶ added in v0.2.2
func (x *QueryEvent) GetNormalizedQuery() string
func (*QueryEvent) GetOp ¶
func (x *QueryEvent) GetOp() int32
func (*QueryEvent) GetQuery ¶
func (x *QueryEvent) GetQuery() string
func (*QueryEvent) GetRowsAffected ¶
func (x *QueryEvent) GetRowsAffected() int64
func (*QueryEvent) GetSlowQuery ¶ added in v0.2.3
func (x *QueryEvent) GetSlowQuery() bool
func (*QueryEvent) GetStartTime ¶
func (x *QueryEvent) GetStartTime() *timestamppb.Timestamp
func (*QueryEvent) GetTxId ¶
func (x *QueryEvent) GetTxId() string
func (*QueryEvent) ProtoMessage ¶
func (*QueryEvent) ProtoMessage()
func (*QueryEvent) ProtoReflect ¶
func (x *QueryEvent) ProtoReflect() protoreflect.Message
func (*QueryEvent) Reset ¶
func (x *QueryEvent) Reset()
func (*QueryEvent) String ¶
func (x *QueryEvent) String() string
type TapServiceClient ¶
type TapServiceClient interface {
Watch(ctx context.Context, in *WatchRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[WatchResponse], error)
Explain(ctx context.Context, in *ExplainRequest, opts ...grpc.CallOption) (*ExplainResponse, error)
}
TapServiceClient is the client API for TapService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewTapServiceClient ¶
func NewTapServiceClient(cc grpc.ClientConnInterface) TapServiceClient
type TapServiceServer ¶
type TapServiceServer interface {
Watch(*WatchRequest, grpc.ServerStreamingServer[WatchResponse]) error
Explain(context.Context, *ExplainRequest) (*ExplainResponse, error)
// contains filtered or unexported methods
}
TapServiceServer is the server API for TapService service. All implementations must embed UnimplementedTapServiceServer for forward compatibility.
type TapService_WatchClient ¶
type TapService_WatchClient = grpc.ServerStreamingClient[WatchResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type TapService_WatchServer ¶
type TapService_WatchServer = grpc.ServerStreamingServer[WatchResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type UnimplementedTapServiceServer ¶
type UnimplementedTapServiceServer struct{}
UnimplementedTapServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedTapServiceServer) Explain ¶
func (UnimplementedTapServiceServer) Explain(context.Context, *ExplainRequest) (*ExplainResponse, error)
func (UnimplementedTapServiceServer) Watch ¶
func (UnimplementedTapServiceServer) Watch(*WatchRequest, grpc.ServerStreamingServer[WatchResponse]) error
type UnsafeTapServiceServer ¶
type UnsafeTapServiceServer interface {
// contains filtered or unexported methods
}
UnsafeTapServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to TapServiceServer will result in compilation errors.
type WatchRequest ¶
type WatchRequest struct {
// contains filtered or unexported fields
}
func (*WatchRequest) Descriptor
deprecated
func (*WatchRequest) Descriptor() ([]byte, []int)
Deprecated: Use WatchRequest.ProtoReflect.Descriptor instead.
func (*WatchRequest) ProtoMessage ¶
func (*WatchRequest) ProtoMessage()
func (*WatchRequest) ProtoReflect ¶
func (x *WatchRequest) ProtoReflect() protoreflect.Message
func (*WatchRequest) Reset ¶
func (x *WatchRequest) Reset()
func (*WatchRequest) String ¶
func (x *WatchRequest) String() string
type WatchResponse ¶
type WatchResponse struct {
Event *QueryEvent `protobuf:"bytes,1,opt,name=event,proto3" json:"event,omitempty"`
// contains filtered or unexported fields
}
func (*WatchResponse) Descriptor
deprecated
func (*WatchResponse) Descriptor() ([]byte, []int)
Deprecated: Use WatchResponse.ProtoReflect.Descriptor instead.
func (*WatchResponse) GetEvent ¶
func (x *WatchResponse) GetEvent() *QueryEvent
func (*WatchResponse) ProtoMessage ¶
func (*WatchResponse) ProtoMessage()
func (*WatchResponse) ProtoReflect ¶
func (x *WatchResponse) ProtoReflect() protoreflect.Message
func (*WatchResponse) Reset ¶
func (x *WatchResponse) Reset()
func (*WatchResponse) String ¶
func (x *WatchResponse) String() string